#!/usr/bin/python3
# -*- coding: utf-8 -*-
import pymysql
def return_sql_info(host,user,passwd,port,sql):
    conn = pymysql.connect(host=host, user=user, passwd=passwd, port=int(port))
    # 获取游标
    global result
    cursor = conn.cursor()
    try:
        # 查询数据
        # print sql
        cursor.execute(sql)
        result = cursor.fetchall()
    except Exception as e:
        conn.rollback()  # 事务回滚
        print('事务处理失败{}'.format(e))
    else:
        conn.commit()  # 事务提交
        # print '事务处理成功'
    cursor.close()  # 先关闭游标
    conn.close()  # 再关闭数据库连接
    # print result
    return result


def return_sql_info_data(host,user,passwd,port,database,sql):
    conn = pymysql.connect(host=host, user=user, passwd=passwd,database=database, port=int(port))
    # 获取游标_test22
    global result
    cursor = conn.cursor()
    try:
        # 查询数据
        # print sql
        cursor.execute(sql)
        result = cursor.fetchall()
    except Exception as e:
        conn.rollback()  # 事务回滚
        print(database)
        print('事务处理失败{}'.format(e))
    else:
        conn.commit()  # 事务提交
        # print '事务处理成功'
    cursor.close()  # 先关闭游标
    conn.close()  # 再关闭数据库连接
    # print result
    return result
def test():
    print("test succeed!!!")


#!/usr/bin/env python
#-*- coding:utf-8 -*-

from setuptools import setup, find_packages

setup(
	name = "damo_mysql_exec",
	version = "2.1",
	url = "http://182.254.246.41/xufangyi/ops/tree/master/damo_mysql_exec",
	long_description = open('README.md').read(),
	packages = find_packages(),
)

'''
name 包的名字
version 依赖关系很重要
packages 需要包含的子包列表，用find_packages()查找
url：包的链接，通常为 Github 上的链接，或者是 readthedocs 链接
setup_requires：指定依赖项
test_suite：测试时运行的工具
'''